@@ -36,28 +36,17 @@
 #include <hildon/hildon-program.h>
 #include <hildon/hildon-file-chooser-dialog.h>
 #include <hildon/hildon-file-system-model.h>
+#include <hildon/hildon-defines.h>
 #include <libosso.h>      /* required for screen saver timeout */
 #define GTK_FM_OK  GTK_RESPONSE_OK
 #define HILDON_ENTRY_NO_AUTOCAP(a) \
   hildon_gtk_entry_set_input_mode(GTK_ENTRY(a),HILDON_GTK_INPUT_MODE_FULL)
-
-#ifndef HILDON_HARDKEY_FULLSCREEN
-#define HILDON_HARDKEY_FULLSCREEN GDK_F6
-#endif
-
-#ifndef HILDON_HARDKEY_INCREASE
-#define HILDON_HARDKEY_INCREASE GDK_F7
-#endif
-
-#ifndef HILDON_HARDKEY_DECREASE
-#define HILDON_HARDKEY_DECREASE GDK_F8
-#endif
-
 #else
 #define GTK_FM_OK  GTK_RESPONSE_ACCEPT
 #define HILDON_ENTRY_NO_AUTOCAP(a)
 #endif
 
+#define ZOOM_BUTTONS  
 
 #include <gtk/gtk.h>
 #include <glib/gstdio.h>
@@ -89,6 +78,10 @@ typedef struct appdata_s {
   struct map_s *map;
   osm_t *osm;
 
+#ifdef ZOOM_BUTTONS
+  GtkWidget *btn_zoom_in, *btn_zoom_out;
+#endif
+
   struct statusbar_s *statusbar;
   struct settings_s *settings;
   struct project_s *project;
@@ -97,7 +90,6 @@ typedef struct appdata_s {
   struct presets_item_s *presets;
 
   /* menu items to be enabled and disabled every now and then */
-  gboolean gps_enabled;
   struct gps_state_s *gps_state;
 
 #ifdef USE_HILDON
@@ -113,38 +105,43 @@ typedef struct appdata_s {
   } dialog_again;
 
   struct {
-    GtkWidget *menu_track;
-    GtkWidget *menu_item_import;
-    GtkWidget *menu_item_export;
-    GtkWidget *menu_item_clear;
-    GtkWidget *menu_item_enable_gps;
-    GtkWidget *menu_item_follow_gps;
+    GtkWidget *submenu_track;
+    GtkWidget *menu_item_track_import;
+    GtkWidget *menu_item_track_export;
+    GtkWidget *menu_item_track_clear;
+    GtkWidget *menu_item_track_enable_gps;
+    GtkWidget *menu_item_track_follow_gps;
     struct track_s *track;
     guint handler_id;
     canvas_item_t *gps_item;      // the purple curcle
   } track;
 
-  GtkWidget *menu_item_project_close;
+#if !defined(USE_HILDON) || (MAEMO_VERSION_MAJOR < 5)
   GtkWidget *menu_item_view_fullscreen;
+#endif
 
-  GtkWidget *menu_view;
+  GtkWidget *submenu_view;
 
-  GtkWidget *menu_osm;
-  GtkWidget *menu_item_osm_upload;
-  GtkWidget *menu_item_osm_undo;
-  GtkWidget *menu_item_osm_save_changes;
-  GtkWidget *menu_item_osm_undo_changes;
-  GtkWidget *menu_item_osm_relations;
+  GtkWidget *submenu_map;
+  GtkWidget *menu_item_map_upload;
+  GtkWidget *menu_item_map_undo;
+  GtkWidget *menu_item_map_save_changes;
+  GtkWidget *menu_item_map_undo_changes;
+  GtkWidget *menu_item_map_relations;
 
-  GtkWidget *menu_wms;
+  GtkWidget *submenu_wms;
   GtkWidget *menu_item_wms_clear;
   GtkWidget *menu_item_wms_adjust;
 
-  GtkWidget *menu_map;
   GtkWidget *menu_item_map_hide_sel;
   GtkWidget *menu_item_map_show_all;
   GtkWidget *menu_item_map_no_icons;
-  GtkWidget *menu_item_map_no_antialias;
+
+#if defined(USE_HILDON) && (MAEMO_VERSION_MAJOR == 5)
+  /* submenues are seperate menues under fremantle */
+  GtkWidget *app_menu_view, *app_menu_wms, *app_menu_track;
+  GtkWidget *app_menu_map;
+#endif
 
   undo_t undo;
 
