@@ -19,19 +19,16 @@
 
 #include "appdata.h"
 
-void messagef(GtkWidget *parent, char *title, const char *fmt, ...) {
-  va_list args;
-  va_start( args, fmt );
+static void vmessagef(GtkWidget *parent, int type, int buttons,
+		      char *title, const char *fmt, 
+		      va_list args) {
+
   char *buf = g_strdup_vprintf(fmt, args);
-  va_end( args );
 
-  printf("%s: \"%s\"\n", title, buf); 
-  
   GtkWidget *dialog = gtk_message_dialog_new(
 		     GTK_WINDOW(parent),
                      GTK_DIALOG_DESTROY_WITH_PARENT,
-                     GTK_MESSAGE_INFO, GTK_BUTTONS_OK,
-                     buf);
+                     type, buttons, buf);
 
   gtk_window_set_title(GTK_WINDOW(dialog), title);
 
@@ -41,6 +38,30 @@ void messagef(GtkWidget *parent, char *title, const char *fmt, ...) {
   g_free(buf);
 }
 
+
+void messagef(GtkWidget *parent, char *title, const char *fmt, ...) {
+  va_list args;
+  va_start( args, fmt );
+  vmessagef(parent, GTK_MESSAGE_INFO, GTK_BUTTONS_OK, title, fmt, args);
+  va_end( args );
+}
+
+void errorf(GtkWidget *parent, const char *fmt, ...) {
+  va_list args;
+  va_start( args, fmt );
+  vmessagef(parent, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, 
+	    _("Error"), fmt, args);
+  va_end( args );
+}
+
+void warningf(GtkWidget *parent, const char *fmt, ...) {
+  va_list args;
+  va_start( args, fmt );
+  vmessagef(parent, GTK_MESSAGE_WARNING, GTK_BUTTONS_CLOSE, 
+	    _("Warning"), fmt, args);
+  va_end( args );
+}
+
 static void on_toggled(GtkWidget *button, gpointer data) {
   gboolean active = 
     gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(button));
@@ -107,28 +128,6 @@ gboolean yes_no_f(GtkWidget *parent, appdata_t *appdata, gulong again_bit,
   return yes;
 }
 
-void errorf(GtkWidget *parent, const char *fmt, ...) {
-  va_list args;
-  va_start( args, fmt );
-  char *buf = g_strdup_vprintf(fmt, args);
-  va_end( args );
-
-  printf("errorf(\"%s\")\n", buf); 
-  
-  GtkWidget *dialog = gtk_message_dialog_new(
-		     GTK_WINDOW(parent),
-                     GTK_DIALOG_DESTROY_WITH_PARENT,
-                     GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE,
-                     buf);
-
-  gtk_window_set_title(GTK_WINDOW(dialog), _("ERROR"));
-
-  gtk_dialog_run(GTK_DIALOG(dialog));
-  gtk_widget_destroy(dialog);
-
-  g_free(buf);
-}
-
 static const char *data_paths[] = {
   "~/." PACKAGE,             // in home directory
   PREFIX "/share/" PACKAGE , // final installation path 
@@ -221,7 +220,7 @@ static const gint dialog_sizes[][2] = {
   { 800, 380 },  // LARGE
 #endif
   { 640, 100 },  // WIDE
-  {   0,   0 },  // HIGH
+  { 450, 480 },  // HIGH
 };
 #else
 static const gint dialog_sizes[][2] = {
@@ -229,7 +228,7 @@ static const gint dialog_sizes[][2] = {
   { 400, 300 },  // MEDIUM
   { 500, 350 },  // LARGE
   { 450, 100 },  // WIDE
-  {   0,   0 },  // HIGH
+  { 200, 350 },  // HIGH
 };
 #endif
 
@@ -291,4 +290,24 @@ void misc_scrolled_window_add_with_viewport(GtkWidget *win, GtkWidget *child) {
 
 #endif
 
+const char *misc_get_proxy_uri(settings_t *settings) {
+  static char proxy_buffer[64];
 
+  /* use environment settings if preset */
+  const char *proxy = g_getenv("http_proxy");
+  if(proxy) return proxy;
+
+  /* otherwise try settings */
+  if(!settings || !settings->proxy || 
+     !settings->proxy->host) return NULL;
+
+  snprintf(proxy_buffer, sizeof(proxy_buffer),
+	   "http://%s:%u", settings->proxy->host,
+	   settings->proxy->port);
+  proxy_buffer[sizeof(proxy_buffer)-1] = 0;
+  return proxy_buffer;
+}
+
+void misc_table_attach(GtkWidget *table, GtkWidget *widget, int x, int y) {
+  gtk_table_attach_defaults(GTK_TABLE(table), widget, x, x+1, y, y+1);
+}
