@@ -93,7 +93,6 @@ gboolean osm_download(GtkWidget *parent, settings_t *settings,
 	     _("It seems your current project uses a server/protocol no "
 	       "longer in use by OSM. It has thus been changed to:\n\n%s"),
 	     project->server);
-    project->dirty = TRUE; // project needs to be changed 
   } else
     printf("url ok\n");
 
@@ -109,14 +108,16 @@ gboolean osm_download(GtkWidget *parent, settings_t *settings,
   if(project->server[strlen(project->server)-1] == '/') {
     printf("removing trailing slash\n");
     project->server[strlen(project->server)-1] = 0;
-    project->dirty = TRUE;
   }
 
   char *url = g_strdup_printf("%s/map?bbox=%s,%s,%s,%s",
 		project->server, minlon, minlat, maxlon, maxlat);
 
-  gboolean result = net_io_download_file(parent, settings, 
-					 url, project->osm);
+  char *str = NULL;
+  if(project->osm[0] == '/') str = g_strdup(project->osm);
+  else str = g_strjoin(NULL, project->path, project->osm, NULL);
+  gboolean result = net_io_download_file(parent, settings, url, str);
+  g_free(str);
 
   g_free(url);
   return result;
@@ -937,7 +938,7 @@ void osm_upload(appdata_t *appdata, osm_t *osm, project_t *project) {
   project_save(GTK_WIDGET(appdata->window), project);
 
   context->dialog = 
-    misc_dialog_new(MISC_DIALOG_LARGE,_("Uploading..."),
+    misc_dialog_new(MISC_DIALOG_LARGE,_("Uploading"),
 	  GTK_WINDOW(appdata->window),
 	  GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE, NULL);
 
@@ -969,7 +970,6 @@ void osm_upload(appdata_t *appdata, osm_t *osm, project_t *project) {
   if(project->server[strlen(project->server)-1] == '/') {
     printf("removing trailing slash\n");
     project->server[strlen(project->server)-1] = 0;
-    project->dirty = TRUE;  /* project needs to be saved */
   }
 
   appendf(&context->log, NULL, _("Log generated by %s v%s using API 0.6\n"), 
@@ -983,7 +983,6 @@ void osm_upload(appdata_t *appdata, osm_t *osm, project_t *project) {
     strstr(project->server, "0.5")[2] = '6';
 
     appendf(&context->log, NULL, _("Adjusting server name to v0.6\n"));
-    project->dirty = TRUE; // project needs to be changed 
   }
 
   appendf(&context->log, NULL, _("Uploading to %s\n"), project->server);
@@ -1046,7 +1045,7 @@ void osm_upload(appdata_t *appdata, osm_t *osm, project_t *project) {
       osm_free(&appdata->icon, appdata->osm);
       
       appendf(&context->log, NULL, _("Loading OSM ...\n"));
-      appdata->osm = osm_parse(appdata->project->osm);
+      appdata->osm = osm_parse(appdata->project->path, appdata->project->osm);
       appendf(&context->log, NULL, _("Applying diff ...\n"));
       diff_restore(appdata, appdata->project, appdata->osm);
       appendf(&context->log, NULL, _("Painting ...\n"));
